#!/bin/sh
############################################################
#	Test Application Framework, Version 1.0
#	Copyright (c)  2008 Marvell Corporation
############################################################
# Usage
usage()
{
	echo "Usage: test_driver.sh [GENERAL_TEST_PARAMETER]... [EXTRA_TEST_PARAMETER]"
	echo ""
	echo "Usage: [GENERAL_TEST_PARAMETER]"
	echo "	-p: test path"	
	echo "	-m: test mode (0 for run, 1 for debug)"
	echo "	-l: test log path name"
	echo "	-c: test case id"
	echo "	-t: time out (millisecond)"
	echo "	-h: usage"
	echo ""	
}

# Parse general parameter
while getopts "p:m:l:c:t:h" OPTION
do
	case $OPTION in
		# Test Path
		"p") TEST_PATH=$OPTARG
			shift 2 ;;
		# Test Mode
		"m") TEST_MODE=$OPTARG
			shift 2 ;;
		# Test Log
		"l") TEST_LOG=$OPTARG
			shift 2 ;;
		# Test Case ID
		"c") TEST_CASE_ID=$OPTARG
			shift 2 ;;
		# Time Out
		"t") TIME_OUT=$OPTARG
			shift 2 ;;		
		# Usage
		"h") USAGE=true
			usage ;;
		# Usage
#		*) USAGE=true
#			usage ;;
	esac
done

# Set default test path
if [ -z "${TEST_PATH}" ]
then TEST_PATH=.
else TEST_PATH=${TEST_PATH%/}
fi

# Set default test mode
if [ -z "$TEST_MODE" ]
then TEST_MODE=0 
fi

# Set default test log
if [ -z "$TEST_LOG" ]
then TEST_LOG=/var/log/test.log
fi

# Set default test case id
if [ -z "$TEST_CASE_ID" ]
then TEST_CASE_ID=TC-COMPONENT-FEATURE-00
fi

# Set default time out (10 hours)
if [ -z "$TIME_OUT" ]
then TIME_OUT=36000000
fi

print_rel_log()
{
	local TIME=`date "+%Y-%m-%d(%Hh:%Mm:%Ss)"`	
	echo -e "$TIME\t|$1" | tee -a $TEST_LOG
}

print_dbg_log()
{
	local TIME=`date "+%Y-%m-%d(%Hh:%Mm:%Ss)"`	
	if [ "0" != "$TEST_MODE" ]
	then echo -e "$TIME\t|$1" | tee -a $TEST_LOG
	fi		
}

print_msg()
{
	echo "$1"
}

print_test_result()
{
	local TIME=`date "+%Y-%m-%d(%Hh:%Mm:%Ss)"`
	if [ "0" -eq "$1" ]
	then 
		echo -e "Test Result: Pass ($TEST_CASE_ID)"
		echo -e "$TIME\t|Test Result: Pass ($TEST_CASE_ID)" >> $TEST_LOG
	else
		echo -e "Test Result: Fail ($TEST_CASE_ID)"
		echo -e "$TIME\t|Test Result: Fail ($TEST_CASE_ID)" >> $TEST_LOG
	fi
}

